==> muse_0.5.2.orig.tar.gz: muse-0.5.2/icons.h <==
//=========================================================
//  MusE
//  Linux Music Editor
//  $Id: icons.h,v 1.2 2001/11/20 15:19:31 muse Exp $
//
//  (C) Copyright 2000 Werner Schweer (ws@seh.de)
//=========================================================

#ifndef ICONS_H
#define ICONS_H

class QPixmap;
class QIconSet;

extern QPixmap* pointerIcon;
extern QPixmap* pencilIcon;
extern QPixmap* deleteIcon;
extern QPixmap* punchinIcon;
extern QPixmap* punchoutIcon;
extern QPixmap* punchin1Icon;
extern QPixmap* punchout1Icon;
extern QPixmap* loopIcon;
extern QPixmap* loop1Icon;
extern QPixmap* playIcon;
extern QPixmap* recordIcon;
extern QPixmap* record1Icon;
extern QPixmap* stopIcon;
extern QPixmap* startIcon;
extern QPixmap* fforwardIcon;
extern QPixmap* frewindIcon;
extern QPixmap* dotIcon;
extern QPixmap* dothIcon;
extern QPixmap* dot1Icon;
extern QPixmap* noteIcon;
extern QPixmap* note1Icon;
extern QPixmap* stickIcon;
extern QPixmap* waveIcon;
extern QPixmap* markIcon[3];

extern QPixmap* cutIcon;
extern QPixmap* steprecIcon;
extern QPixmap* glueIcon;
extern QPixmap* drawIcon;

extern QPixmap* quantIcon;
extern QPixmap* printIcon;
extern QPixmap* printIconS;
extern QPixmap* openIcon;
extern QPixmap* saveIcon;
extern QPixmap* openIconS;
extern QPixmap* saveIconS;
extern QPixmap* archiveIcon;
extern QPixmap* findIcon;
extern QPixmap* masterIcon;
extern QPixmap* filenewIcon;
extern QPixmap* filenewIconS;
extern QPixmap* homeIcon;
extern QPixmap* backIcon;
extern QPixmap* forwardIcon;
extern QPixmap* muteIcon;
extern QPixmap* upIcon;
extern QPixmap* downIcon;
extern QPixmap* boldIcon;
extern QPixmap* italicIcon;
extern QPixmap* underlinedIcon;
extern QPixmap* gvIcon;
extern QPixmap* midiinIcon;
extern QPixmap* sysexIcon;
extern QPixmap* ctrlIcon;
extern QPixmap* metaIcon;
extern QPixmap* pitchIcon;
extern QPixmap* cafterIcon;
extern QPixmap* pafterIcon;
extern QPixmap* flagIcon;
extern QPixmap* flagIconS;
extern QPixmap* lockIcon;
extern QPixmap* tocIcon;
extern QPixmap* exitIconS;

extern QPixmap* undoIcon;
extern QPixmap* redoIcon;
extern QPixmap* undoIconS;
extern QPixmap* redoIconS;

extern QPixmap* speakerIcon;
extern QPixmap* buttondownIcon;
extern QPixmap* configureIcon;

extern QIconSet* pianoIconSet;
extern QIconSet* scoreIconSet;
extern QIconSet* editcutIconSet;
extern QIconSet* editcopyIconSet;
extern QIconSet* editpasteIconSet;
#endif

==> muse_0.6.3.orig.tar.gz: muse-0.6.3/icons.h <==
//=========================================================
//  MusE
//  Linux Music Editor
//  $Id: icons.h,v 1.1.1.1 2003/10/29 10:05:13 wschweer Exp $
//
//  (C) Copyright 2000 Werner Schweer (ws@seh.de)
//=========================================================

#ifndef ICONS_H
#define ICONS_H

class QPixmap;
class QIconSet;

extern QPixmap* pointerIcon;
extern QPixmap* pencilIcon;
extern QPixmap* deleteIcon;
extern QPixmap* punchinIcon;
extern QPixmap* punchoutIcon;
extern QPixmap* punchin1Icon;
extern QPixmap* punchout1Icon;
extern QPixmap* loopIcon;
extern QPixmap* loop1Icon;
extern QPixmap* playIcon;
extern QPixmap* recordIcon;
extern QPixmap* record1Icon;
extern QPixmap* stopIcon;
extern QPixmap* startIcon;
extern QPixmap* fforwardIcon;
extern QPixmap* frewindIcon;
extern QPixmap* dotIcon;
extern QPixmap* dothIcon;
extern QPixmap* dot1Icon;
extern QPixmap* noteIcon;
extern QPixmap* note1Icon;
extern QPixmap* stickIcon;
extern QPixmap* waveIcon;
extern QPixmap* markIcon[3];

extern QPixmap* cutIcon;
extern QPixmap* steprecIcon;
extern QPixmap* glueIcon;
extern QPixmap* drawIcon;

extern QPixmap* quantIcon;
extern QPixmap* printIcon;
extern QPixmap* printIconS;
extern QPixmap* openIcon;
extern QPixmap* saveIcon;
extern QPixmap* openIconS;
extern QPixmap* saveIconS;
extern QPixmap* archiveIcon;
extern QPixmap* findIcon;
extern QPixmap* masterIcon;
extern QPixmap* filenewIcon;
extern QPixmap* filenewIconS;
extern QPixmap* homeIcon;
extern QPixmap* backIcon;
extern QPixmap* forwardIcon;
extern QPixmap* muteIcon;
extern QPixmap* upIcon;
extern QPixmap* downIcon;
extern QPixmap* boldIcon;
extern QPixmap* italicIcon;
extern QPixmap* underlinedIcon;
extern QPixmap* gvIcon;
extern QPixmap* midiinIcon;
extern QPixmap* sysexIcon;
extern QPixmap* ctrlIcon;
extern QPixmap* metaIcon;
extern QPixmap* pitchIcon;
extern QPixmap* cafterIcon;
extern QPixmap* pafterIcon;
extern QPixmap* flagIcon;
extern QPixmap* flagIconS;
extern QPixmap* lockIcon;
extern QPixmap* tocIcon;
extern QPixmap* exitIconS;

extern QPixmap* undoIcon;
extern QPixmap* redoIcon;
extern QPixmap* undoIconS;
extern QPixmap* redoIconS;

extern QPixmap* speakerIcon;
extern QPixmap* buttondownIcon;
extern QPixmap* configureIcon;

extern QPixmap* editmuteIcon;
extern QPixmap* editmuteSIcon;
extern QPixmap* panicIcon;

extern QIconSet* pianoIconSet;
extern QIconSet* scoreIconSet;
extern QIconSet* editcutIconSet;
extern QIconSet* editmuteIconSet;
extern QIconSet* editcopyIconSet;
extern QIconSet* editpasteIconSet;

extern QPixmap* exitIcon;
extern QPixmap* recordonIcon;
extern QPixmap* recordoffIcon;
extern QPixmap* newmuteIcon;
extern QPixmap* soloIcon;

extern QPixmap* greendotIcon;
extern QPixmap* darkgreendotIcon;
extern QPixmap* reddotIcon;
extern QPixmap* darkreddotIcon;
extern QPixmap* graydotIcon;
extern QPixmap* bluedotIcon;
extern QPixmap* offIcon;
#endif
